import { reactive, ref, computed, watch, inject } from 'vue'
import useTable, { ModelType, MultipleResponseType } from '@/hooks/useTable'
import { ROLE } from '@/constants/dicts'

import type { EpTableProps, EpTableColumn } from 'global-type'

// function mockNumber(min = 1, max = 10000) {
//   return Math.random() * (max - min + 1) + min
// }

// function mockBoolean() {
//   return Math.random() > 0.5
// }

// function mockString() {
//   return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
//     const r = (Math.random() * 16) | 0,
//       v = c == 'x' ? r : (r & 0x3) | 0x8
//     return v.toString(16)
//   })
// }

// function mockRole() {
//   return Object.keys(ROLE)[((Math.random() * 10000) | 0) % 4] as ROLE
// }

// const defaultUserList = Array.from({ length: 10 }).map((_) => {
//   const role = mockRole()
//   return {
//     id: mockNumber(1, 30),
//     enable: mockBoolean(),
//     examId: mockNumber(),
//     groupId: mockNumber(),
//     loginName: mockString(),
//     markingGroupNumber: mockNumber(),
//     name: mockString(),
//     role,
//     roleName: ROLE[role],
//     subjectCode: mockString(),
//     createTime: '2022-10-17 09:22:33',
//     updateTime: '2022-10-17 09:22:33',
//     updaterName: mockString(),
//   } as MultipleResponseType<'getUserList'>
// })

const useUserManageTable = (model?: ModelType<'getUserList'>) => {
  const { data, ...other } = useTable('getUserList', model)

  const columns: EpTableColumn<MultipleResponseType<'getUserList'>>[] = [
    { type: 'selection' },
    { label: 'ID', prop: 'id' },
    { label: '姓名', prop: 'name' },
    { label: '登录名', prop: 'loginName' },
    { label: '角色', prop: 'roleName', width: 80 },
    {
      label: '状态',
      prop: 'enable',
      width: 50,
      formatter(row) {
        return row.enable ? '启用' : '禁用'
      },
    },
    { label: '更新人', prop: 'updaterName' },
    { label: '更新时间', prop: 'updateTime' },
    { label: '操作', slotName: 'operation', showOverflowTooltip: false, minWidth: 80 },
  ]

  return {
    ...other,
    columns,
    data,
  }
}

export default useUserManageTable
